==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/KubeControllerManagerStatusFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface KubeControllerManagerStatusFluent<A extends io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.OperatorCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.OperatorCondition item);
  public A addToConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> items);
  public A removeFromConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> items);
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> getConditions();
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> buildConditions();
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition buildCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition buildFirstCondition();
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition buildLastCondition();
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> predicate);
  public A withConditions(java.util.List<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> conditions);
  public A withConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... conditions);
  public java.lang.Boolean hasConditions();
  public A addNewCondition(java.lang.String lastTransitionTime,java.lang.String message,java.lang.String reason,java.lang.String status,java.lang.String type);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.ConditionsNested<A> addNewCondition();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.openshift.api.model.operator.v1.OperatorCondition item);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.OperatorCondition item);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.ConditionsNested<A> editFirstCondition();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.ConditionsNested<A> editLastCondition();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> predicate);
  public A addToGenerations(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.GenerationStatus item);
  public A setToGenerations(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.GenerationStatus item);
  public A addToGenerations(io.fabric8.openshift.api.model.operator.v1.GenerationStatus... items);
  public A addAllToGenerations(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.GenerationStatus> items);
  public A removeFromGenerations(io.fabric8.openshift.api.model.operator.v1.GenerationStatus... items);
  public A removeAllFromGenerations(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.GenerationStatus> items);
  public A removeMatchingFromGenerations(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.GenerationStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildGenerations instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.GenerationStatus> getGenerations();
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.GenerationStatus> buildGenerations();
  public io.fabric8.openshift.api.model.operator.v1.GenerationStatus buildGeneration(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.GenerationStatus buildFirstGeneration();
  public io.fabric8.openshift.api.model.operator.v1.GenerationStatus buildLastGeneration();
  public io.fabric8.openshift.api.model.operator.v1.GenerationStatus buildMatchingGeneration(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.GenerationStatusBuilder> predicate);
  public java.lang.Boolean hasMatchingGeneration(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.GenerationStatusBuilder> predicate);
  public A withGenerations(java.util.List<io.fabric8.openshift.api.model.operator.v1.GenerationStatus> generations);
  public A withGenerations(io.fabric8.openshift.api.model.operator.v1.GenerationStatus... generations);
  public java.lang.Boolean hasGenerations();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.GenerationsNested<A> addNewGeneration();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.GenerationsNested<A> addNewGenerationLike(io.fabric8.openshift.api.model.operator.v1.GenerationStatus item);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.GenerationsNested<A> setNewGenerationLike(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.GenerationStatus item);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.GenerationsNested<A> editGeneration(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.GenerationsNested<A> editFirstGeneration();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.GenerationsNested<A> editLastGeneration();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.GenerationsNested<A> editMatchingGeneration(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.GenerationStatusBuilder> predicate);
  public java.lang.Integer getLatestAvailableRevision();
  public A withLatestAvailableRevision(java.lang.Integer latestAvailableRevision);
  public java.lang.Boolean hasLatestAvailableRevision();
  public java.lang.String getLatestAvailableRevisionReason();
  public A withLatestAvailableRevisionReason(java.lang.String latestAvailableRevisionReason);
  public java.lang.Boolean hasLatestAvailableRevisionReason();
  
  /**
   * Method is deprecated. use withLatestAvailableRevisionReason instead.
   */
  @java.lang.Deprecated
  public A withNewLatestAvailableRevisionReason(java.lang.String arg0);
  public A addToNodeStatuses(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.NodeStatus item);
  public A setToNodeStatuses(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.NodeStatus item);
  public A addToNodeStatuses(io.fabric8.openshift.api.model.operator.v1.NodeStatus... items);
  public A addAllToNodeStatuses(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.NodeStatus> items);
  public A removeFromNodeStatuses(io.fabric8.openshift.api.model.operator.v1.NodeStatus... items);
  public A removeAllFromNodeStatuses(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.NodeStatus> items);
  public A removeMatchingFromNodeStatuses(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.NodeStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildNodeStatuses instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.NodeStatus> getNodeStatuses();
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.NodeStatus> buildNodeStatuses();
  public io.fabric8.openshift.api.model.operator.v1.NodeStatus buildNodeStatus(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.NodeStatus buildFirstNodeStatus();
  public io.fabric8.openshift.api.model.operator.v1.NodeStatus buildLastNodeStatus();
  public io.fabric8.openshift.api.model.operator.v1.NodeStatus buildMatchingNodeStatus(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.NodeStatusBuilder> predicate);
  public java.lang.Boolean hasMatchingNodeStatus(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.NodeStatusBuilder> predicate);
  public A withNodeStatuses(java.util.List<io.fabric8.openshift.api.model.operator.v1.NodeStatus> nodeStatuses);
  public A withNodeStatuses(io.fabric8.openshift.api.model.operator.v1.NodeStatus... nodeStatuses);
  public java.lang.Boolean hasNodeStatuses();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.NodeStatusesNested<A> addNewNodeStatus();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.NodeStatusesNested<A> addNewNodeStatusLike(io.fabric8.openshift.api.model.operator.v1.NodeStatus item);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.NodeStatusesNested<A> setNewNodeStatusLike(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.NodeStatus item);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.NodeStatusesNested<A> editNodeStatus(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.NodeStatusesNested<A> editFirstNodeStatus();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.NodeStatusesNested<A> editLastNodeStatus();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.NodeStatusesNested<A> editMatchingNodeStatus(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.NodeStatusBuilder> predicate);
  public java.lang.Long getObservedGeneration();
  public A withObservedGeneration(java.lang.Long observedGeneration);
  public java.lang.Boolean hasObservedGeneration();
  public java.lang.Integer getReadyReplicas();
  public A withReadyReplicas(java.lang.Integer readyReplicas);
  public java.lang.Boolean hasReadyReplicas();
  public java.lang.String getVersion();
  public A withVersion(java.lang.String version);
  public java.lang.Boolean hasVersion();
  
  /**
   * Method is deprecated. use withVersion instead.
   */
  @java.lang.Deprecated
  public A withNewVersion(java.lang.String arg0);
  public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.OperatorConditionFluent<io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface GenerationsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.GenerationStatusFluent<io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.GenerationsNested<N>>{
    public N and();
    public N endGeneration();
    
  }
  public interface NodeStatusesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.NodeStatusFluent<io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.NodeStatusesNested<N>>{
    public N and();
    public N endNodeStatus();
    
  }
  
}

==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/KubeControllerManagerStatusFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface KubeControllerManagerStatusFluent<A extends io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.OperatorCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.OperatorCondition item);
  public A addToConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> items);
  public A removeFromConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> items);
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> getConditions();
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> buildConditions();
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition buildCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition buildFirstCondition();
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition buildLastCondition();
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> predicate);
  public A withConditions(java.util.List<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> conditions);
  public A withConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... conditions);
  public java.lang.Boolean hasConditions();
  public A addNewCondition(java.lang.String lastTransitionTime,java.lang.String message,java.lang.String reason,java.lang.String status,java.lang.String type);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.ConditionsNested<A> addNewCondition();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.openshift.api.model.operator.v1.OperatorCondition item);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.OperatorCondition item);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.ConditionsNested<A> editFirstCondition();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.ConditionsNested<A> editLastCondition();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> predicate);
  public A addToGenerations(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.GenerationStatus item);
  public A setToGenerations(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.GenerationStatus item);
  public A addToGenerations(io.fabric8.openshift.api.model.operator.v1.GenerationStatus... items);
  public A addAllToGenerations(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.GenerationStatus> items);
  public A removeFromGenerations(io.fabric8.openshift.api.model.operator.v1.GenerationStatus... items);
  public A removeAllFromGenerations(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.GenerationStatus> items);
  public A removeMatchingFromGenerations(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.GenerationStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildGenerations instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.GenerationStatus> getGenerations();
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.GenerationStatus> buildGenerations();
  public io.fabric8.openshift.api.model.operator.v1.GenerationStatus buildGeneration(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.GenerationStatus buildFirstGeneration();
  public io.fabric8.openshift.api.model.operator.v1.GenerationStatus buildLastGeneration();
  public io.fabric8.openshift.api.model.operator.v1.GenerationStatus buildMatchingGeneration(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.GenerationStatusBuilder> predicate);
  public java.lang.Boolean hasMatchingGeneration(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.GenerationStatusBuilder> predicate);
  public A withGenerations(java.util.List<io.fabric8.openshift.api.model.operator.v1.GenerationStatus> generations);
  public A withGenerations(io.fabric8.openshift.api.model.operator.v1.GenerationStatus... generations);
  public java.lang.Boolean hasGenerations();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.GenerationsNested<A> addNewGeneration();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.GenerationsNested<A> addNewGenerationLike(io.fabric8.openshift.api.model.operator.v1.GenerationStatus item);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.GenerationsNested<A> setNewGenerationLike(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.GenerationStatus item);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.GenerationsNested<A> editGeneration(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.GenerationsNested<A> editFirstGeneration();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.GenerationsNested<A> editLastGeneration();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.GenerationsNested<A> editMatchingGeneration(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.GenerationStatusBuilder> predicate);
  public java.lang.Integer getLatestAvailableRevision();
  public A withLatestAvailableRevision(java.lang.Integer latestAvailableRevision);
  public java.lang.Boolean hasLatestAvailableRevision();
  public java.lang.String getLatestAvailableRevisionReason();
  public A withLatestAvailableRevisionReason(java.lang.String latestAvailableRevisionReason);
  public java.lang.Boolean hasLatestAvailableRevisionReason();
  
  /**
   * Method is deprecated. use withLatestAvailableRevisionReason instead.
   */
  @java.lang.Deprecated
  public A withNewLatestAvailableRevisionReason(java.lang.String arg0);
  public A addToNodeStatuses(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.NodeStatus item);
  public A setToNodeStatuses(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.NodeStatus item);
  public A addToNodeStatuses(io.fabric8.openshift.api.model.operator.v1.NodeStatus... items);
  public A addAllToNodeStatuses(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.NodeStatus> items);
  public A removeFromNodeStatuses(io.fabric8.openshift.api.model.operator.v1.NodeStatus... items);
  public A removeAllFromNodeStatuses(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.NodeStatus> items);
  public A removeMatchingFromNodeStatuses(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.NodeStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildNodeStatuses instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.NodeStatus> getNodeStatuses();
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.NodeStatus> buildNodeStatuses();
  public io.fabric8.openshift.api.model.operator.v1.NodeStatus buildNodeStatus(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.NodeStatus buildFirstNodeStatus();
  public io.fabric8.openshift.api.model.operator.v1.NodeStatus buildLastNodeStatus();
  public io.fabric8.openshift.api.model.operator.v1.NodeStatus buildMatchingNodeStatus(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.NodeStatusBuilder> predicate);
  public java.lang.Boolean hasMatchingNodeStatus(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.NodeStatusBuilder> predicate);
  public A withNodeStatuses(java.util.List<io.fabric8.openshift.api.model.operator.v1.NodeStatus> nodeStatuses);
  public A withNodeStatuses(io.fabric8.openshift.api.model.operator.v1.NodeStatus... nodeStatuses);
  public java.lang.Boolean hasNodeStatuses();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.NodeStatusesNested<A> addNewNodeStatus();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.NodeStatusesNested<A> addNewNodeStatusLike(io.fabric8.openshift.api.model.operator.v1.NodeStatus item);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.NodeStatusesNested<A> setNewNodeStatusLike(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.NodeStatus item);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.NodeStatusesNested<A> editNodeStatus(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.NodeStatusesNested<A> editFirstNodeStatus();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.NodeStatusesNested<A> editLastNodeStatus();
  public io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.NodeStatusesNested<A> editMatchingNodeStatus(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.NodeStatusBuilder> predicate);
  public java.lang.Long getObservedGeneration();
  public A withObservedGeneration(java.lang.Long observedGeneration);
  public java.lang.Boolean hasObservedGeneration();
  public java.lang.Integer getReadyReplicas();
  public A withReadyReplicas(java.lang.Integer readyReplicas);
  public java.lang.Boolean hasReadyReplicas();
  public java.lang.String getVersion();
  public A withVersion(java.lang.String version);
  public java.lang.Boolean hasVersion();
  
  /**
   * Method is deprecated. use withVersion instead.
   */
  @java.lang.Deprecated
  public A withNewVersion(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.OperatorConditionFluent<io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface GenerationsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.GenerationStatusFluent<io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.GenerationsNested<N>>{
    public N and();
    public N endGeneration();
    
  }
  public interface NodeStatusesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.NodeStatusFluent<io.fabric8.openshift.api.model.operator.v1.KubeControllerManagerStatusFluent.NodeStatusesNested<N>>{
    public N and();
    public N endNodeStatus();
    
  }
  
}
